==> wp2-be-metadata-dm-1.0.1-20251229.141210-4-sources.jar: com/finconsgroup/itserr/marketplace/metadata/dm/entity/ArchivedMetadataEntity.java <==
package com.finconsgroup.itserr.marketplace.metadata.dm.entity;

import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.EnumType;
import jakarta.persistence.Enumerated;
import jakarta.persistence.OneToMany;
import jakarta.persistence.Table;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.List;
import java.util.UUID;

import com.finconsgroup.itserr.marketplace.metadata.dm.entity.enumerated.MetadataCategoryEnum;

/**
 * This entity represents a soft deleted {@link MetadataEntity}.
 * But it doesn't have unique constraints on name field.
 */
@Entity
@Table(name = "archived_metadata")
@SuperBuilder
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
public class ArchivedMetadataEntity extends AbstractUUIDEntity {

    /**
     * Name field length.
     */
    public static final int NAME_LENGTH = 50;

    /**
     * Description field length.
     */
    public static final int DESCRIPTION_LENGTH = 2000;

    /**
     * Metadata name.
     */
    @Column(name = "name", nullable = false, length = NAME_LENGTH)
    private String name;

    /**
     * Metadata description.
     */
    @Column(name = "description", length = DESCRIPTION_LENGTH)
    private String description;

    /**
     * Metadata category.
     */
    @Enumerated(EnumType.STRING)
    @Column(name = "category", nullable = false)
    private MetadataCategoryEnum category;

    /**
     * The ID of the user who created the Metadata.
     */
    @Column(name = "creator_id")
    private UUID creatorId;

    /**
     * Metadata fields.
     */
    //TODO: may we use JPA Metamodel constants?
    @OneToMany(mappedBy = "metadata", cascade = CascadeType.ALL, orphanRemoval = true)
    private List<ArchivedMetadataFieldEntity> fields;
}

==> wp2-be-metadata-dm-1.0.2-20260123.060932-1-sources.jar: com/finconsgroup/itserr/marketplace/metadata/dm/entity/ArchivedMetadataEntity.java <==
package com.finconsgroup.itserr.marketplace.metadata.dm.entity;

import com.finconsgroup.itserr.marketplace.metadata.dm.dto.MetadataStatus;
import jakarta.persistence.CascadeType;
import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.EnumType;
import jakarta.persistence.Enumerated;
import jakarta.persistence.OneToMany;
import jakarta.persistence.Table;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.time.Instant;
import java.util.List;
import java.util.UUID;

import com.finconsgroup.itserr.marketplace.metadata.dm.entity.enumerated.MetadataCategoryEnum;

/**
 * This entity represents a soft deleted {@link MetadataEntity}.
 * But it doesn't have unique constraints on name field.
 */
@Entity
@Table(name = "archived_metadata")
@SuperBuilder
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
public class ArchivedMetadataEntity extends AbstractUUIDEntity {

    /**
     * Name field length.
     */
    public static final int NAME_LENGTH = 50;

    /**
     * Description field length.
     */
    public static final int DESCRIPTION_LENGTH = 2000;

    /**
     * Metadata name.
     */
    @Column(name = "name", nullable = false, length = NAME_LENGTH)
    private String name;

    /**
     * Metadata description.
     */
    @Column(name = "description", length = DESCRIPTION_LENGTH)
    private String description;

    /**
     * Metadata category.
     */
    @Enumerated(EnumType.STRING)
    @Column(name = "category", nullable = false)
    private MetadataCategoryEnum category;

    /**
     * The ID of the user who created the Metadata.
     */
    @Column(name = "creator_id")
    private UUID creatorId;

    /**
     * Metadata fields.
     */
    //TODO: may we use JPA Metamodel constants?
    @OneToMany(mappedBy = "metadata", cascade = CascadeType.ALL, orphanRemoval = true)
    private List<ArchivedMetadataFieldEntity> fields;

    /**
     * The current status of the metadata.
     */
    @Enumerated(EnumType.STRING)
    @Column(name = "status")
    private MetadataStatus status;

    /**
     * The moderation message associated with this metadata.
     */
    @Column(name = "moderation_message")
    private String moderationMessage;

    /**
     * The timestamp when this metadata detail was created.
     */
    @Column(name = "created_at")
    private Instant createdAt;

    /**
     * The timestamp when this metadata detail was last updated.
     */
    @Column(name = "updated_at")
    private Instant updatedAt;

    /**
     * The UUID of the user who last updated this metadata detail.
     */
    @Column(name = "updated_by", columnDefinition = "UUID")
    private UUID updatedBy;

    @Column(name = "version")
    private long version;

    /**
     * The timestamp when the metadata was last archived.
     */
    @Column(name = "archived_at", nullable = false)
    private Instant archivedAt;

    @Override
    public void prePersist() {
        super.prePersist();
        Instant now = Instant.now();
        if (createdAt == null) {
            createdAt = now;
        }
        if (updatedAt == null) {
            updatedAt = now;
        }
        if (archivedAt == null) {
            archivedAt = now;
        }
    }
}
